@@ -20,9 +20,11 @@ class MultitaskPopulation(Population):
     atoms.info['data']['raw_scores']**. After providing the raw scores, 
     **the effective score of each configuration is automatically 
     calculated and stored in atoms.info['key_value_pairs']['raw_score']**.
-    The niches that benefit the most from each configuration are stored in
-    atoms.info['data']['niches'], and the dominating niche is stored in
-    atoms.info['key_value_pairs']['dominating_niche'].
+    The dominating niche of each configuration is stored in 
+    atoms.info['key_value_pairs']['dominating_niche'], the best niche 
+    (i.e. the niche closest to the upper envelope) is stored in 
+    atoms.info['key_value_pairs']['best_niche'], and the niches that are 
+    dominated by the dominating niche are stored in atoms.info['data']['niches'].
 
     Parameters
     ----------
@@ -140,15 +142,17 @@ class MultitaskPopulation(Population):
                               self.max_scores[min_loss_niche], 8))
                 new_cand[i].info['key_value_pairs']['raw_score'] = f_eff
                 new_cand[i].info['key_value_pairs']['dominating_niche'] = dominating_niche
+                new_cand[i].info['key_value_pairs']['best_niche'] = min_loss_niche
                 new_cand[i].info['data']['niches'] = np.argwhere(
-                    self.dominating_niches==dominating_niche).flatten() 
+                        self.dominating_niches==dominating_niche).flatten() 
  
             # Update the fitness of all previously-relaxed candidates if fitness     
             # is gained at any niche from the new generation (niche migration)
             updated_cand = []
-            if gained_ids and len(self.pop) > 0:
+            if gained_ids and (len(self.pop) > 0):
                 # Update the database        
                 prev_cand = self.dc.get_all_relaxed_candidates()
+                prev_cand.sort(key=lambda x: x.info['confid'])
                 del_ids = [] 
                 for a in prev_cand:
                     scores = a.info['data']['raw_scores']
@@ -158,8 +162,9 @@ class MultitaskPopulation(Population):
                                   self.max_scores[min_loss_niche], 8))
                     a.info['key_value_pairs']['raw_score'] = f_eff
                     a.info['key_value_pairs']['dominating_niche'] = dominating_niche
+                    a.info['key_value_pairs']['best_niche'] = min_loss_niche
                     a.info['data']['niches'] = np.argwhere(
-                        self.dominating_niches==dominating_niche).flatten() 
+                            self.dominating_niches==dominating_niche).flatten() 
                     updated_cand.append(a)
                     gaid = a.info['confid']
                     del_ids.append(gaid)
